# Qnverter
Python crossplatform application for quick text conversions.

### What is Qnverter
its a quick way of converting any textbased contents in a fast and easy way, wich also means you dont't have to give up your data to some website on the internet just to be able to convert a few json files. 
The entire application is written in pure python and uses the PyQt module to generate the GUI. You can also install new scripts from inside the application with the press of a button.

# Schreenshots
![schreenshot1.png](schreenshot1.png)
![screenshot2.png](screenshot2.png)

feel free to create your own scripts